#
# spec file for package ghc-OneTuple
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name OneTuple
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.4.2
Release:        2.2
Summary:        Singleton Tuple
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-hashable-prof
%endif

%description
This package is a compatibility package for a singleton data type

> data Solo a = MkSolo a

Note: it's not a 'newtype'

'Solo' is available in 'base-4.16' (GHC-9.2).

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc Changelog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Fri Dec 20 2024 Peter Simons <psimons@suse.com>
- Update OneTuple to version 0.4.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun May 12 2024 Peter Simons <psimons@suse.com>
- Update OneTuple to version 0.4.2.
  Upstream has not updated the file "Changelog.md" since the last
  release.
* Thu Nov 16 2023 Peter Simons <psimons@suse.com>
- Drop obsolete dependency on ghc-foldable1-classes-compat.
* Wed Oct  4 2023 Peter Simons <psimons@suse.com>
- Update OneTuple to version 0.4.1.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Jun  1 2023 Peter Simons <psimons@suse.com>
- Update OneTuple to version 0.4.1.1.
  [#] 0.4.1.1
  - Support GHC-7.2 and GHC-7.0.
  [#] 0.4.1
  - Mark `MkSolo` pattern synonym as `COMPLETE`
  [#] 0.4
  - Rename constructor to `MkSolo` as in `base-4.17`.
    The compatibility pattern synonym is provided.
  - Add `Foldable1 Solo` instance
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Aug 10 2022 Peter Simons <psimons@suse.com>
- Update OneTuple to version 0.3.1 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Nov 16 2021 psimons@suse.com
- Update OneTuple to version 0.3.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Add OneTuple at version 0.3.1.
